@@ -134,7 +134,7 @@ class TableRow(object):
 
     def __repr__(self):
         """Human-readable TableRow representation"""
-        return '<TableRow(%s)>' % str(self.cells)
+        return '<TableRow(%s)>' % unicode(self.cells)
 
     def __iter__(self):
         """Return each of the row's cells in turn"""
@@ -193,7 +193,7 @@ class RowSpec(object):
 
     def __repr__(self):
         """Human-readable RowSpec representation"""
-        return '<RowSpec(%s)>' % str(self.columnspecs)
+        return '<RowSpec(%s)>' % unicode(self.columnspecs)
 
     def __call__(self, rowobject):
         """A RowSpec can be used as a factory that can take an object
@@ -202,11 +202,12 @@ class RowSpec(object):
         object."""
         output = []
         for column in self.columnspecs:
+            value = rowobject
             for attribute in column.attributes:
                 try:
-                    value = rowobject[attribute]
+                    value = value[attribute]
                 except (KeyError, TypeError):
-                    value = getattr(rowobject, attribute)
+                    value = getattr(value, attribute)
             output.append(Cell(value, column.style))
         return TableRow(*output)
 
@@ -266,7 +267,7 @@ class TableBase(object):
             return value
         if value is None:
             return ''
-        castfunction = self.castfunctions.get(type(value), str)
+        castfunction = self.castfunctions.get(type(value), unicode)
         return cgi.escape(castfunction(value))
 
 class PDFTable(TableBase):
@@ -474,7 +475,32 @@ class SpreadsheetTable(TableBase):
 class HTMLTable(TableBase):
     """Table generator that yields an HTML representation of the
     data. Note that this class yields *only* the table itself and not
-    an entire HTML document."""
+    an entire HTML document.
+
+    The CSS classes are compatible with jQuery's tablesorter plugin
+    <http://tablesorter.com/docs/>. With this combination, all
+    generated tables can be sorted in a client's browser just by
+    clicking on the column headers.
+
+    When a rowset is made of multiple TableRow objects, all rows after
+    the first are additionally assigned the 'childrow' CSS class. This
+    adds compatibility with the "Children Rows" mod to tablesorter
+    <http://www.pengoworks.com/workshop/jquery/tablesorter/tablesorter.htm>,
+    which groups child rows with their parent rows when sorting.
+
+    For example, the following lines in a page's <head> section will
+    enable all of those client-side options:
+    
+        <script type="text/javascript" src="/javascript/jquery-1.5.min.js"></script> 
+        <script type="text/javascript" src="/javascript/jquery.tablesorter.min.js"></script> 
+        <script type="text/javascript" src="/javascript/jquery.tablesorter.mod.js"></script> 
+        <script type="text/javascript">                                         
+        $(document).ready(function() 
+            { 
+                $(".reporttable").tablesorter({widgets: ['zebra']}); 
+            } 
+        );
+    """
 
     # These are the CSS classes emitted by the renderer
     cssdefs = {
@@ -482,6 +508,7 @@ class HTMLTable(TableBase):
         'money'   : 'cell_money',
         'table'   : 'reporttable',
         'childrow': 'expand-child',
+        'zebra'   : ('odd', 'even'),
         }
     
     def _rendercell(self, cell):
@@ -542,7 +569,7 @@ class HTMLTable(TableBase):
             if isinstance(rowset, TableRow):
                 rowset = [rowset]
             for subrowindex, subrow in enumerate(rowset):
-                trclasses = [('odd', 'even')[rowsetindex % 2]]
+                trclasses = [self.cssdefs['zebra'][rowsetindex % 2]]
                 if subrowindex:
                     trclasses.append(self.cssdefs['childrow'])
                 lines.append('    <tr class="%s">' % ' '.join(trclasses))
